@@ -442,7 +442,7 @@ class HydraPy:
         await asyncio.gather(f1, f2)
 
     async def log(self, severity, entry, text=None):
-        entry = {
+        new_entry = {
             'serviceName': self._service_name,
             'version': self._service_version,
             'instanceID': self._instance_id,
@@ -450,15 +450,14 @@ class HydraPy:
             'body': {}
         }
         if text:
-            entry['message'] = text
+            new_entry['message'] = text
         if entry:
-            entry['body'] = entry
-        msg = (UMF_Message()).create_message({
+            new_entry['body'] = entry
+        await self.send_broadcast_message((UMF_Message()).create_message({
             'to': 'hydra-logging-svcs:/',
             'from': f'{self._service_name}:/',
-            'body': entry
-        })
-        await self.send_message(msg)
+            'body': new_entry
+        }))
 
     async def _health_check_event(self):
         tr = self._redis.multi_exec()
